@@ -48,7 +48,8 @@
  * Local defines
  */
 #define PID_ROOT                1
-#define PID_EMPTY               0
+#define PID_ZERO                0 // In containers, if attached from the host
+#define PID_UNKNOWN             -1
 
 #define PROC_PID_STATUS_KEY_NAME        "Name"
 #define PROC_PID_STATUS_KEY_PPID        "PPid"
@@ -127,17 +128,14 @@ char* read_proc_property (int pid, char* prop_name)
         /*
          * Separate line content into two tokens: key and value
          * If separation fails, continue to the next line ("Groups:" key is one such example)
-         *
-         * Explicitly initialized as pointer to "", otherwise coverity complains with
-         * "Uninitialized pointer read (UNINIT)".
          */
-        char *savePtr = "";
-        k = strtok_r(line, ":", &savePtr);
-        v = strtok_r(NULL, ":", &savePtr);
+        k = line;
+        v = strchr(line, ':');
         if (NULL == v) {
             continue;
         }
-
+        *v = '\0';
+        v++;
         /* The key we are looking for? */
         if (strcmp(prop_name, k) == 0) {
             /* Yes! */
@@ -154,7 +152,7 @@ char* read_proc_property (int pid, char* prop_name)
                 strncpy(returnValue, v, PROC_PID_STATUS_VAL_MAX_LENGTH);
                 returnValue[PROC_PID_STATUS_VAL_MAX_LENGTH_STR-1] = 0; // Change newline into null character
             } else {
-                strncpy(returnValue, v, PROC_PID_STATUS_VAL_MAX_LENGTH_STR);
+                strncpy(returnValue, v, PROC_PID_STATUS_VAL_MAX_LENGTH_STR-1);
             }
 
             // Do a cleanup and return a string duplicate, which should be freed by the caller
@@ -193,7 +191,7 @@ int get_parent_pid (int pid)
         return ppid_int;
     }
 
-    return PID_EMPTY;
+    return PID_UNKNOWN;
 }
 
 
@@ -206,7 +204,7 @@ int get_rpname (int pid, char *result)
     size_t  nameLen;
 
     parentPid = get_parent_pid(pid);
-    if (PID_ROOT == parentPid) {
+    if ((PID_ROOT == parentPid) || (PID_ZERO == parentPid)) {
         name = read_proc_property(pid, PROC_PID_STATUS_KEY_NAME);
         if (NULL != name) {
             nameLen = snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", name);
@@ -215,7 +213,7 @@ int get_rpname (int pid, char *result)
             nameLen = snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", UNKNOWN_STR);
         }
         return nameLen;
-    } else if (PID_EMPTY == parentPid) {
+    } else if (PID_UNKNOWN == parentPid) {
         return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", UNKNOWN_STR);
     } else {
         return get_rpname(parentPid, result);
